@@ -729,7 +729,7 @@ static void on_selection_done(GtkMenu *menu, gpointer unused)
 {
     GtkWidget *widget = gtk_menu_get_attach_widget(menu);
 
-    g_debug("FmPlacesView:on_selection_done(): attached widget %p", widget);
+    /* g_debug("FmPlacesView:on_selection_done(): attached widget %p", widget); */
     if (widget) /* it may be destroyed and detached already */
         g_object_weak_unref(G_OBJECT(widget), (GWeakNotify)gtk_menu_detach, menu);
     gtk_widget_destroy(GTK_WIDGET(menu));
@@ -790,22 +790,25 @@ static GtkWidget* place_item_get_menu(FmPlacesItem* item, GtkWidget *widget)
     }
     else if(fm_places_item_get_type(item) == FM_PLACES_ITEM_VOLUME)
     {
+        GVolume *vol = fm_places_item_get_volume(item);
         GMount* mnt;
         char *unix_path = NULL;
         gtk_action_group_add_actions(act_grp, vol_menu_actions, G_N_ELEMENTS(vol_menu_actions), item);
         gtk_ui_manager_add_ui_from_string(ui, vol_menu_xml, -1, NULL);
 
-        mnt = g_volume_get_mount(fm_places_item_get_volume(item));
+        mnt = g_volume_get_mount(vol);
         if(mnt) /* mounted */
         {
             g_object_unref(mnt);
             act = gtk_action_group_get_action(act_grp, "Mount");
             gtk_action_set_visible(act, FALSE);
+            act = gtk_action_group_get_action(act_grp, "Unmount");
+            gtk_action_set_sensitive(act, g_mount_can_unmount(mnt));
         }
         else /* not mounted */
         {
             if (fm_config->format_cmd && fm_config->format_cmd[0])
-                unix_path = g_volume_get_identifier(fm_places_item_get_volume(item),
+                unix_path = g_volume_get_identifier(vol,
                                                     G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE);
             if (unix_path && unix_path[0] != '/') /* we can format only local */
             {
@@ -815,6 +818,8 @@ static GtkWidget* place_item_get_menu(FmPlacesItem* item, GtkWidget *widget)
             g_free(unix_path); /* use it to mark only */
             act = gtk_action_group_get_action(act_grp, "Unmount");
             gtk_action_set_visible(act, FALSE);
+            act = gtk_action_group_get_action(act_grp, "Mount");
+            gtk_action_set_sensitive(act, g_volume_can_mount(vol));
         }
         if (unix_path == NULL)
         {
@@ -841,6 +846,8 @@ static GtkWidget* place_item_get_menu(FmPlacesItem* item, GtkWidget *widget)
         {
             act = gtk_action_group_get_action(act_grp, "Mount");
             gtk_action_set_sensitive(act, FALSE);
+            act = gtk_action_group_get_action(act_grp, "Unmount");
+            gtk_action_set_sensitive(act, g_mount_can_unmount(mnt));
         }
         else /* not mounted */
         {
@@ -850,6 +857,8 @@ static GtkWidget* place_item_get_menu(FmPlacesItem* item, GtkWidget *widget)
         act = gtk_action_group_get_action(act_grp, "Format");
         if (act)
              gtk_action_set_visible(act, FALSE);
+        act = gtk_action_group_get_action(act_grp, "Eject");
+        gtk_action_set_visible(act, FALSE);
     }
     else
         goto _out;
@@ -868,6 +877,7 @@ static GtkWidget* place_item_get_menu(FmPlacesItem* item, GtkWidget *widget)
            Unmount therefore we should detach menu to avoid crash
            note that we should remove this ref when we destroy menu */
         g_object_weak_ref(G_OBJECT(widget), (GWeakNotify)gtk_menu_detach, menu);
+        gtk_ui_manager_ensure_update(ui);
     }
 
 _out:
@@ -917,13 +927,22 @@ static void popup_position_func(GtkMenu *menu, gint *x, gint *y,
     if(rtl) /* RTL */
     {
         x2 = cell.x + cell.width;
-        *x = CLAMP(*x, MIN(cell.x + ma.width, x2), x2);
+        if (*x < cell.x + ma.width) /* out of monitor */
+            *x = MIN(*x + ma.width, x2); /* place menu right to cursor */
+        else
+            *x = MIN(*x, x2);
     }
     else /* LTR */
     {
-        *x = CLAMP(*x, cell.x, MAX(cell.x, cell.x + cell.width - ma.width));
+        if (*x + ma.width > cell.x + cell.width) /* out of monitor */
+            *x = MAX(cell.x, *x - ma.width); /* place menu left to cursor */
+        else
+            *x = MAX(cell.x, *x); /* place menu right to cursor */
     }
-    *y = CLAMP(*y, cell.y, MAX(cell.y, cell.y + cell.height - ma.height));
+    if (*y + ma.height > cell.y + cell.height) /* out of monitor */
+        *y = MAX(cell.y, *y - ma.height); /* place menu above cursor */
+    else
+        *y = MAX(cell.y, *y); /* place menu below cursor */
 }
 
 static void fm_places_item_popup(GtkWidget *widget, GtkTreeIter *it, guint32 time)
